@@ -1,8 +1,8 @@
 package AFS::PTS;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)$RCS-Id: src/PTS/PTS.pm 7a64d4d Wed May 1 22:05:49 2013 +0200 Norbert E Gruener$"
+# RCS-Id: "@(#)PTS.pm,v 2.1 2002/07/04 06:00:35 nog Exp"
 #
-# © 2001-2010 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
@@ -13,7 +13,7 @@ use AFS ();
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(AFS);
-$VERSION = 'v2.6.4';
+$VERSION = sprintf("%d.%02d", q/2.1/ =~ /(\d+)\.(\d+)/);
 
 sub new {
     # this whole construct is to please the old version from Roland
@@ -27,12 +27,6 @@ sub new {
     AFS::PTS::_new('AFS::PTS', @args);
 }
 
-sub DESTROY {
-    my (undef, undef, undef, $subroutine) = caller(1);
-    if (! defined $subroutine or $subroutine !~ /eval/) { undef $_[0]; }  # self->DESTROY
-    else { AFS::PTS::_DESTROY($_[0]); }                                   # undef self
-}
-
 sub ascii2ptsaccess {
     my $class  = shift;
 
